@@ -59,6 +59,7 @@ module.exports = {
         "ipify",
         "java",
         "julia",
+        "kotlin",
         "kubectl",
         "nbgv",
         "nightscout",
@@ -76,6 +77,7 @@ module.exports = {
         "shell",
         "spotify",
         "strava",
+        "swift",
         "sysinfo",
         "terraform",
         "text",
