@@ -41,7 +41,6 @@ type Block struct {
 	ansi                  *color.Ansi
 	activeSegment         *Segment
 	previousActiveSegment *Segment
-	length                int
 }
 
 func (b *Block) init(env environment.Environment, writer color.Writer, ansi *color.Ansi) {
@@ -71,7 +70,7 @@ func (b *Block) enabled() bool {
 		return true
 	}
 	for _, segment := range b.Segments {
-		if segment.active {
+		if segment.enabled {
 			return true
 		}
 	}
@@ -93,7 +92,7 @@ func (b *Block) renderSegmentsText() {
 func (b *Block) renderSegments() (string, int) {
 	defer b.writer.Reset()
 	for _, segment := range b.Segments {
-		if !segment.active {
+		if !segment.enabled {
 			continue
 		}
 		b.renderSegment(segment)
@@ -174,11 +173,11 @@ func (b *Block) debug() (int, []*SegmentTiming) {
 		}
 		start := time.Now()
 		segment.renderText(b.env)
-		segmentTiming.active = segment.active
+		segmentTiming.active = segment.enabled
 		segmentTiming.text = segment.text
 		if segmentTiming.active {
 			b.renderSegment(segment)
-			segmentTiming.text, b.length = b.writer.String()
+			segmentTiming.text, _ = b.writer.String()
 			b.writer.Reset()
 		}
 		segmentTiming.duration = time.Since(start)
