@@ -37,7 +37,7 @@ const (
 	plain       = "shell"
 )
 
-func getExecutablePath(shell string) (string, error) {
+func getExecutablePath(env environment.Environment) (string, error) {
 	executable, err := os.Executable()
 	if err != nil {
 		return "", err
@@ -46,36 +46,38 @@ func getExecutablePath(shell string) (string, error) {
 	// which uses unix style paths to resolve the executable's location.
 	// PowerShell knows how to resolve both, so we can swap this without any issue.
 	executable = strings.ReplaceAll(executable, "\\", "/")
-	switch shell {
+	switch *env.Args().Shell {
 	case bash, zsh:
 		executable = strings.ReplaceAll(executable, " ", "\\ ")
 		executable = strings.ReplaceAll(executable, "(", "\\(")
 		executable = strings.ReplaceAll(executable, ")", "\\)")
-		return executable, nil
 	}
 	return executable, nil
 }
 
-func InitShell(shell, configFile string) string {
-	executable, err := getExecutablePath(shell)
+func InitShell(env environment.Environment) string {
+	executable, err := getExecutablePath(env)
 	if err != nil {
 		return noExe
 	}
+	shell := *env.Args().Shell
 	switch shell {
 	case pwsh, powershell5:
-		return fmt.Sprintf("(@(&\"%s\" --print-init --shell=%s --config=\"%s\") -join \"`n\") | Invoke-Expression", executable, shell, configFile)
+		return fmt.Sprintf("(@(&\"%s\" --print-init --shell=%s --config=\"%s\") -join \"`n\") | Invoke-Expression", executable, shell, *env.Args().Config)
 	case zsh, bash, fish, winCMD:
-		return PrintShellInit(shell, configFile)
+		return PrintShellInit(env)
 	default:
 		return fmt.Sprintf("echo \"No initialization script available for %s\"", shell)
 	}
 }
 
-func PrintShellInit(shell, configFile string) string {
-	executable, err := getExecutablePath(shell)
+func PrintShellInit(env environment.Environment) string {
+	executable, err := getExecutablePath(env)
 	if err != nil {
 		return noExe
 	}
+	shell := *env.Args().Shell
+	configFile := *env.Args().Config
 	switch shell {
 	case pwsh, powershell5:
 		return getShellInitScript(executable, configFile, pwshInit)
