@@ -29,7 +29,7 @@ type Segment struct {
 
 	writer          SegmentWriter
 	text            string
-	active          bool
+	enabled         bool
 	env             environment.Environment
 	backgroundCache string
 	foregroundCache string
@@ -158,6 +158,10 @@ const (
 	CF SegmentType = "cf"
 	// Cloud Foundry logged in target
 	CFTARGET SegmentType = "cftarget"
+	// KOTLIN writes the active kotlin version
+	KOTLIN SegmentType = "kotlin"
+	// SWIFT writes the active swift version
+	SWIFT SegmentType = "swift"
 )
 
 func (segment *Segment) shouldIncludeFolder() bool {
@@ -284,6 +288,8 @@ func (segment *Segment) mapSegmentWithWriter(env environment.Environment) error
 		UI5TOOLING:    &segments.UI5Tooling{},
 		CF:            &segments.Cf{},
 		CFTARGET:      &segments.CfTarget{},
+		KOTLIN:        &segments.Kotlin{},
+		SWIFT:         &segments.Swift{},
 	}
 	if segment.Properties == nil {
 		segment.Properties = make(properties.Map)
@@ -320,7 +326,7 @@ func (segment *Segment) renderText(env environment.Environment) {
 		message := fmt.Sprintf("\noh-my-posh fatal error rendering %s segment:%s\n\n%s\n", segment.Type, err, debug.Stack())
 		fmt.Println(message)
 		segment.text = "error"
-		segment.active = true
+		segment.enabled = true
 	}()
 	err := segment.mapSegmentWithWriter(env)
 	if err != nil || !segment.shouldIncludeFolder() {
@@ -328,6 +334,6 @@ func (segment *Segment) renderText(env environment.Environment) {
 	}
 	if segment.writer.Enabled() {
 		segment.text = segment.string()
-		segment.active = len(strings.TrimSpace(segment.text)) > 0
+		segment.enabled = len(strings.ReplaceAll(segment.text, " ", "")) > 0
 	}
 }
